Date: 08 29, 2001 10:52:03 AM

# Running the Rule Generator

To run the rule generator:

1. From the Analyzer menu, select Generate Rules.

2. Select All to generate all rules as specified by samples in the Gram Tab.

Note: The Dirty and Unlocked options are used to generate rules for rule concepts that have the Dirty or Unlocked attribute set. For more information on generating rules using Dirty or Unlocked, see Generating Rules. See Setting Rule Generation Properties for more information on other attributes.

WARNING: The edits to automatically generated pass files will not be saved the next time you try to regenerate the rules. The only ways to permanently modify automatically generated files are (1) to add or edit samples in the Gram Tab and regenerate the rules, (2) to move or copy the files out of a stub region.